@@ -2,7 +2,7 @@ use strict;
 
 package HTML::Restrict;
 {
-  $HTML::Restrict::VERSION = '2.0.0';
+  $HTML::Restrict::VERSION = '2.1.0';
 }
 
 use Moo;
@@ -101,10 +101,15 @@ sub _build_parser {
                 croak "All tag names must be lower cased";
             }
             if ( reftype $rules->{$tag_name} eq 'ARRAY' ) {
-                foreach my $attr_name ( @{ $rules->{$tag_name} } ) {
-                    if ( lc $attr_name ne $attr_name ) {
-                        croak "All attribute names must be lower cased";
-                    }
+                my @attr_names;
+                foreach my $attr_item ( @{ $rules->{$tag_name} } ) {
+                    ref $attr_item eq 'HASH'
+                        ? push(@attr_names, keys(%$attr_item))
+                        : push(@attr_names, $attr_item);
+                }
+                for (@attr_names) {
+                    croak "All attribute names must be lower cased"
+                        if lc $_ ne $_;
                 }
             }
         }
@@ -141,12 +146,23 @@ sub _build_parser {
                     }
 
                     foreach
-                        my $attribute ( @{ $self->get_rules->{$tagname} } )
+                        my $attr_item ( @{ $self->get_rules->{$tagname} } )
                     {
-                        if ( exists $attr->{$attribute}
-                            && $attribute ne q{/} )
-                        {
-                            $more .= qq[ $attribute="$attr->{$attribute}" ];
+                        if (ref $attr_item eq 'HASH') {
+                            # validate against regex contraints
+                            for my $attr_name (sort keys %$attr_item) {
+                                if ( exists $attr->{$attr_name} ) {
+                                    $more .= qq[ $attr_name="$attr->{$attr_name}" ]
+                                        if $attr->{$attr_name} =~ $attr_item->{$attr_name};
+                                }
+                            }
+                        }
+                        else {
+                            my $attr_name = $attr_item;
+                            if ( exists $attr->{$attr_name} ) {
+                                $more .= qq[ $attr_name="$attr->{$attr_name}" ]
+                                    unless $attr_name eq q{/};
+                            }
                         }
                     }
 
@@ -296,7 +312,7 @@ HTML::Restrict - Strip unwanted HTML tags and attributes
 
 =head1 VERSION
 
-version 2.0.0
+version 2.1.0
 
 =head1 SYNOPSIS
 
@@ -325,7 +341,7 @@ version 2.0.0
 
 =head1 DESCRIPTION
 
-This module uses I<HTML::Parser> to strip HTML from text in a restrictive
+This module uses L<HTML::Parser> to strip HTML from text in a restrictive
 manner.  By default all HTML is restricted.  You may alter the default
 behaviour by supplying your own tag rules.
 
@@ -398,7 +414,7 @@ Allow bolded text, images and some (but not all) image attributes:
     );
     my $hr = HTML::Restrict->new( rules => \%rules );
 
-Since I<HTML::Parser> treats a closing slash as an attribute, you'll need to
+Since L<HTML::Parser> treats a closing slash as an attribute, you'll need to
 add "/" to your list of allowed attributes if you'd like your tags to retain
 closing slashes.  For example:
 
@@ -429,13 +445,25 @@ element order you don't need to pay any attention to this, but you should be
 aware that your elements are being reconstructed rather than just stripped
 down.
 
-Also note that all tag and attribute names must be supplied in lower case.
+As of 2.1.0, you can also specify a regex to be tested against the attribute
+value. This feature should be considered experimental for the time being:
 
-    # correct
-    my $hr = HTML::Restrict->new( rules => { body => ['onload'] } );
+    my $hr = HTML::Restrict->new(
+        rules => {
+            iframe => [
+                qw( width height allowfullscreen ),
+                {   src         => qr{^http://www\.youtube\.com},
+                    frameborder => qr{^(0|1)$},
+                }
+            ],
+            img => [ qw( alt ), { src => qr{^/my/images/} }, ],
+        },
+    );
 
-    # throws a fatal error
-    my $hr = HTML::Restrict->new( rules => { Body => ['onLoad'] } );
+    my $html = '<img src="http://www.example.com/image.jpg" alt="Alt Text">';
+    my $processed = $hr->process( $html );
+
+    # $processed now equals: <img alt="Alt Text">
 
 =item * C<< trim => [0|1] >>
 
@@ -535,6 +563,17 @@ This is the method which does the real work.  It parses your data, removes any
 tags and attributes which are not specifically allowed and returns the
 resulting text.  Requires and returns a SCALAR.
 
+=head1 CAVEATS
+
+Please note that all tag and attribute names passed via the rules param must be
+supplied in lower case.
+
+    # correct
+    my $hr = HTML::Restrict->new( rules => { body => ['onload'] } );
+
+    # throws a fatal error
+    my $hr = HTML::Restrict->new( rules => { Body => ['onLoad'] } );
+
 =head1 MOTIVATION
 
 There are already several modules on the CPAN which accomplish much of the same
